@@ -16,7 +16,7 @@ VERSION = 0.1
 
 __all__ = ["main", "VERSION"]
 
-import sys, logging, os
+import sys, logging, os, traceback
 from optparse import OptionParser
 
 from colorama import *
@@ -134,16 +134,24 @@ def run():
         if not os.path.basename(name) in pukefiles:
             executeTask(name.strip())
         
-        
+def gettraceback():
+    trace = ""
+    exception = ""
+    exc_list = traceback.format_exception_only (sys.exc_type, sys.exc_value)
+    for entry in exc_list:
+        exception += entry
+    tb_list = traceback.format_tb(sys.exc_info()[2])
+    for entry in tb_list[-1]:
+        trace += entry  
+    return trace  
 
 def main():
     try:
         run()
     
     except Exception as error:
-        exc_type, exc_obj, exc_tb = sys.exc_info()
 
-        console.fail("\n\n :puke: \n PUKE %s ( line : %s)\n" % (error, exc_tb.tb_lineno))
+        console.fail("\n\n :puke: \n PUKE %s \n %s \n" % (error, gettraceback()))
 
         sys.exit(1)
         
